@@ -410,6 +410,7 @@ INTERSECT
  FROM d2
  GROUP BY y
  LIMIT 3)
+\n\
 LIMIT 2
 
 /*
@@ -479,14 +480,15 @@ WHERE t1.code LIKE (SELECT t2.code || '.%'
 with recursive t(n) as (values (1) union all select n+1 from t where n < 100)
 select sum(n) from t;
 =
-WITH RECURSIVE t(n) AS
-     (VALUES (1)
+WITH RECURSIVE
+     t(n) AS
+       (VALUES (1)
 \n\
-      UNION ALL
+        UNION ALL
 \n\
-      SELECT n + 1
-      FROM t
-      WHERE n < 100)
+        SELECT n + 1
+        FROM t
+        WHERE n < 100)
 \n\
   SELECT sum(n)
   FROM t
@@ -495,11 +497,11 @@ with cte_1 as (select 1), cte_2 as (select * from cte_1)
 select * from cte_2
 =
 WITH cte_1 AS
-     (SELECT 1)
+       (SELECT 1)
 \n\
    , cte_2 AS
-     (SELECT *
-      FROM cte_1)
+       (SELECT *
+        FROM cte_1)
 \n\
   SELECT *
   FROM cte_2
@@ -587,3 +589,21 @@ FROM json_table(favorites, '$.favorites[*]'
                                                          , bname text PATH '$.name'
                                                          , NESTED PATH '$.authors[*]' COLUMNS (author_id FOR ORDINALITY
                                                                                              , author_name text PATH '$.name'))))
+
+select 1+2+3+4, 1*2*3, 'a'||'b'||'c'
+=
+SELECT 1 + 2 + 3 + 4
+     , 1 * 2 * 3
+     , 'a' || 'b' || 'c'
+
+select a from table1 union all select x from table2 order by a
+=
+SELECT a
+FROM table1
+\n\
+UNION ALL
+\n\
+SELECT x
+FROM table2
+\n\
+ORDER BY a
